=== modified file 'bzrlib/osutils.py'
--- bzrlib/osutils.py	2007-01-03 00:22:24 +0000
+++ bzrlib/osutils.py	2007-01-04 20:06:16 +0000
@@ -25,6 +25,7 @@
 
 from bzrlib.lazy_import import lazy_import
 lazy_import(globals(), """
+from datetime import datetime
 import errno
 from ntpath import (abspath as _nt_abspath,
                     join as _nt_join,
@@ -554,14 +555,10 @@
 
 def local_time_offset(t=None):
     """Return offset of local zone from GMT, either at present or at time t."""
-    # python2.3 localtime() can't take None
     if t is None:
         t = time.time()
-        
-    if time.localtime(t).tm_isdst and time.daylight:
-        return -time.altzone
-    else:
-        return -time.timezone
+    offset = datetime.fromtimestamp(t) - datetime.utcfromtimestamp(t)
+    return offset.days * 86400 + offset.seconds
 
     
 def format_date(t, offset=0, timezone='original', date_fmt=None, 

=== modified file 'bzrlib/tests/test_osutils.py'
--- bzrlib/tests/test_osutils.py	2006-11-02 07:29:02 +0000
+++ bzrlib/tests/test_osutils.py	2007-01-04 10:45:55 +0000
@@ -677,3 +677,24 @@
         self.assertEqual(None, os.environ.get('BZR_TEST_ENV_VAR'))
         self.failIf('BZR_TEST_ENV_VAR' in os.environ)
 
+
+class TestLocalTimeOffset(TestCase):
+
+    def test_local_time_offset(self):
+        """Test that local_time_offset() returns a sane value."""
+        offset = osutils.local_time_offset()
+        self.assertTrue(isinstance(offset, int))
+        # Test that the offset is no more than a eighteen hours in
+        # either direction.
+        # Time zone handling is system specific, so it is difficult to
+        # do more specific tests, but a value outside of this range is
+        # probably wrong.
+        eighteen_hours = 18 * 3600
+        self.assertTrue(-eighteen_hours < offset < eighteen_hours)
+
+    def test_local_time_offset_with_timestamp(self):
+        """Test that local_time_offset() works with a timestamp."""
+        offset = osutils.local_time_offset(1000000000.1234567)
+        self.assertTrue(isinstance(offset, int))
+        eighteen_hours = 18 * 3600
+        self.assertTrue(-eighteen_hours < offset < eighteen_hours)

